@@ -1,5 +1,8 @@
 #include "collapse_c.h"
 // #include "data.table.h"
+// #ifndef USE_RINTERNALS
+// #define USE_RINTERNALS
+// #endif
 
 void matCopyAttr(SEXP out, SEXP x, SEXP Rdrop, int ng) {
   SEXP dn = getAttrib(x, R_DimNamesSymbol);
@@ -110,27 +113,44 @@ SEXP gsplit(SEXP x, SEXP gobj, SEXP toint) {
   const int ng = length(gs), *pgs = INTEGER(gs), tx = TYPEOF(x), l = length(g);
   if(ng != INTEGER(VECTOR_ELT(gobj, 0))[0]) error("'GRP' object needs to have valid vector of group-sizes");
   SEXP res = PROTECT(allocVector(VECSXP, ng));
-  SEXP *pres = SEXPPTR(res);
   // Output as integer or not
   if(asLogical(toint)) {
-    for(int i = 0; i != ng; ++i) pres[i] = allocVector(INTSXP, pgs[i]);
+    for(int i = 0; i != ng; ++i) SET_VECTOR_ELT(res, i, allocVector(INTSXP, pgs[i]));
   } else { // Allocate split vectors and copy attributes and object bits
-    copyMostAttrib(x, res);
-    SEXP ax = ATTRIB(res);
-    SET_ATTRIB(res, R_NilValue);
-    if(TYPEOF(ax) != NILSXP && OBJECT(x) != 0) {
-      for(int i = 0, ox = OBJECT(x); i != ng; ++i) {
-        SET_ATTRIB(pres[i] = allocVector(tx, pgs[i]), ax);
-        SET_OBJECT(pres[i], ox);
+    SEXP x1 = PROTECT(allocVector(tx, 1));
+    copyMostAttrib(x, x1);
+    SEXP ax = ATTRIB(x1);
+    if(length(ax) == 1 && TAG(ax) == install("label")) ax = R_NilValue;
+    int ox = OBJECT(x);
+    // FAZIT: Need to use SET_VECTOR_ELT!! pres[i] = allocVector() doesn't work!!
+    if(TYPEOF(ax) != NILSXP && ox != 0) {
+      for(int i = 0, s4o = IS_S4_OBJECT(x); i != ng; ++i) {
+        SEXP resi;
+        SET_VECTOR_ELT(res, i, resi = allocVector(tx, pgs[i]));
+        SET_ATTRIB(resi, ax);
+        SET_OBJECT(resi, ox);
+        if(s4o) SET_S4_OBJECT(resi);
       }
     } else if(TYPEOF(ax) != NILSXP) {
-      for(int i = 0; i != ng; ++i) SET_ATTRIB(pres[i] = allocVector(tx, pgs[i]), ax);
-    } else if(OBJECT(x) != 0) { // Is this even possible? Object bits but no attributes?
-      for(int i = 0, ox = OBJECT(x); i != ng; ++i) SET_OBJECT(pres[i] = allocVector(tx, pgs[i]), ox);
+      for(int i = 0; i != ng; ++i) {
+        SEXP resi;
+        SET_VECTOR_ELT(res, i, resi = allocVector(tx, pgs[i])); // SET_ATTRIB(pres[i] = allocVector(tx, pgs[i]), ax);
+        SET_ATTRIB(resi, ax);
+      }
+    } else if(ox != 0) { // Is this even possible? Object bits but no attributes?
+      for(int i = 0, s4o = IS_S4_OBJECT(x); i != ng; ++i) {
+        SEXP resi;
+        SET_VECTOR_ELT(res, i, resi = allocVector(tx, pgs[i]));
+        SET_OBJECT(resi, ox);
+        if(s4o) SET_S4_OBJECT(resi);
+      }
     } else {
-      for(int i = 0; i != ng; ++i) pres[i] = allocVector(tx, pgs[i]);
+      for(int i = 0; i != ng; ++i) SET_VECTOR_ELT(res, i, allocVector(tx, pgs[i]));
     }
+    UNPROTECT(1);
   }
+
+  SEXP *pres = SEXPPTR(res);
   // If grouping is sorted
   if(LOGICAL(ord)[1] == 1) { // This only works if data is already ordered in order of the groups
     int count = 0;
@@ -200,14 +220,15 @@ SEXP gsplit(SEXP x, SEXP gobj, SEXP toint) {
       }
     }
   } else if(length(order) == l) { // Grouping not sorted but we have the ordering..
-
-    const SEXP starts = getAttrib(order, install("starts"));
+    SEXP sym_starts = PROTECT(install("starts"));
+    const SEXP starts = getAttrib(order, sym_starts);
+    UNPROTECT(1);
     if(length(starts) != ng) goto unsno;
     const int *po = INTEGER(order), *ps = INTEGER(starts);
 
     if(asLogical(toint)) {
-      for(int i = 0, *pri; i != ng; ++i) {
-        pri = INTEGER(pres[i]);
+      for(int i = 0; i != ng; ++i) {
+        int *pri = INTEGER(pres[i]);
         for(int j = ps[i]-1, end = ps[i]+pgs[i]-1, k = 0; j < end; j++) pri[k++] = po[j];
       }
     } else {
@@ -216,8 +237,8 @@ SEXP gsplit(SEXP x, SEXP gobj, SEXP toint) {
       case INTSXP:
       case LGLSXP: {
         const int *px = INTEGER(x);
-        for(int i = 0, *pri; i != ng; ++i) {
-          pri = INTEGER(pres[i]);
+        for(int i = 0; i != ng; ++i) {
+          int *pri = INTEGER(pres[i]);
           for(int j = ps[i]-1, end = ps[i]+pgs[i]-1, k = 0; j < end; ++j) pri[k++] = px[po[j]-1];
         }
         break;
@@ -265,6 +286,7 @@ SEXP gsplit(SEXP x, SEXP gobj, SEXP toint) {
       default: error("Unsupported type '%s' passed to gsplit", type2char(tx));
       }
     }
+
   } else { // Unsorted, without ordering
     unsno:;
     int *count = (int*)Calloc(ng, int);
@@ -353,7 +375,9 @@ SEXP greorder(SEXP x, SEXP gobj) {
 
   // Note: This is only faster for a large number of groups...
   if(length(order) == l) { // Grouping not sorted but we have the ordering..
-    const SEXP starts = getAttrib(order, install("starts"));
+    SEXP sym_starts = PROTECT(install("starts"));
+    const SEXP starts = getAttrib(order, sym_starts);
+    UNPROTECT(1);
     if(length(starts) != ng) goto unsno2;
     const int *po = INTEGER(order), *ps = INTEGER(starts);
 
